==> create-fly-1.21.8-6.0.8-1-sources.jar: com/zurrtum/create/content/contraptions/bearing/WindmillBearingBlockEntity.java <==
package com.zurrtum.create.content.contraptions.bearing;

import com.zurrtum.create.AllAdvancements;
import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.foundation.advancement.CreateTrigger;
import com.zurrtum.create.foundation.blockEntity.behaviour.BlockEntityBehaviour;
import com.zurrtum.create.foundation.blockEntity.behaviour.scrollValue.ServerScrollOptionBehaviour;
import com.zurrtum.create.infrastructure.config.AllConfigs;
import java.util.List;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3532;

public class WindmillBearingBlockEntity extends MechanicalBearingBlockEntity {

    protected ServerScrollOptionBehaviour<RotationDirection> movementDirection;
    protected float lastGeneratedSpeed;

    protected boolean queuedReassembly;

    public WindmillBearingBlockEntity(class_2338 pos, class_2680 state) {
        super(AllBlockEntityTypes.WINDMILL_BEARING, pos, state);
    }

    @Override
    public void updateGeneratedRotation() {
        super.updateGeneratedRotation();
        lastGeneratedSpeed = getGeneratedSpeed();
        queuedReassembly = false;
    }

    @Override
    public void onSpeedChanged(float prevSpeed) {
        boolean cancelAssembly = assembleNextTick;
        super.onSpeedChanged(prevSpeed);
        assembleNextTick = cancelAssembly;
    }

    @Override
    public void tick() {
        super.tick();
        if (field_11863.method_8608())
            return;
        if (!queuedReassembly)
            return;
        queuedReassembly = false;
        if (!running)
            assembleNextTick = true;
    }

    public void disassembleForMovement() {
        if (!running)
            return;
        disassemble();
        queuedReassembly = true;
    }

    @Override
    public float getGeneratedSpeed() {
        if (!running)
            return 0;
        if (movedContraption == null)
            return lastGeneratedSpeed;
        int sails = ((BearingContraption) movedContraption.getContraption()).getSailBlocks() / AllConfigs.server().kinetics.windmillSailsPerRPM.get();
        return class_3532.method_15340(sails, 1, 16) * getAngleSpeedDirection();
    }

    @Override
    public boolean isWindmill() {
        return true;
    }

    protected float getAngleSpeedDirection() {
        RotationDirection rotationDirection = RotationDirection.values()[movementDirection.getValue()];
        return (rotationDirection == RotationDirection.CLOCKWISE ? 1 : -1);
    }

    @Override
    public void write(class_11372 view, boolean clientPacket) {
        view.method_71464("LastGenerated", lastGeneratedSpeed);
        view.method_71472("QueueAssembly", queuedReassembly);
        super.write(view, clientPacket);
    }

    @Override
    protected void read(class_11368 view, boolean clientPacket) {
        if (!wasMoved)
            lastGeneratedSpeed = view.method_71423("LastGenerated", 0);
        queuedReassembly = view.method_71433("QueueAssembly", false);
        super.read(view, clientPacket);
    }

    @Override
    public void addBehaviours(List<BlockEntityBehaviour<?>> behaviours) {
        movementDirection = new ServerScrollOptionBehaviour<>(RotationDirection.class, this);
        movementDirection.withCallback($ -> onDirectionChanged());
        behaviours.add(movementDirection);
    }

    @Override
    public List<CreateTrigger> getAwardables() {
        return List.of(AllAdvancements.WINDMILL, AllAdvancements.WINDMILL_MAXED);
    }

    private void onDirectionChanged() {
        if (!running)
            return;
        if (!field_11863.field_9236)
            updateGeneratedRotation();
    }

    @Override
    public boolean isWoodenTop() {
        return true;
    }

    public enum RotationDirection {
        CLOCKWISE,
        COUNTER_CLOCKWISE;
    }

}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/content/contraptions/bearing/WindmillBearingBlockEntity.java <==
package com.zurrtum.create.content.contraptions.bearing;

import com.zurrtum.create.AllAdvancements;
import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.foundation.advancement.CreateTrigger;
import com.zurrtum.create.foundation.blockEntity.behaviour.BlockEntityBehaviour;
import com.zurrtum.create.foundation.blockEntity.behaviour.scrollValue.ServerScrollOptionBehaviour;
import com.zurrtum.create.infrastructure.config.AllConfigs;
import java.util.List;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3532;

public class WindmillBearingBlockEntity extends MechanicalBearingBlockEntity {

    protected ServerScrollOptionBehaviour<RotationDirection> movementDirection;
    protected float lastGeneratedSpeed;

    protected boolean queuedReassembly;

    public WindmillBearingBlockEntity(class_2338 pos, class_2680 state) {
        super(AllBlockEntityTypes.WINDMILL_BEARING, pos, state);
    }

    @Override
    public void updateGeneratedRotation() {
        super.updateGeneratedRotation();
        lastGeneratedSpeed = getGeneratedSpeed();
        queuedReassembly = false;
    }

    @Override
    public void onSpeedChanged(float prevSpeed) {
        boolean cancelAssembly = assembleNextTick;
        super.onSpeedChanged(prevSpeed);
        assembleNextTick = cancelAssembly;
    }

    @Override
    public void tick() {
        super.tick();
        if (field_11863.method_8608())
            return;
        if (!queuedReassembly)
            return;
        queuedReassembly = false;
        if (!running)
            assembleNextTick = true;
    }

    public void disassembleForMovement() {
        if (!running)
            return;
        disassemble();
        queuedReassembly = true;
    }

    @Override
    public float getGeneratedSpeed() {
        if (!running)
            return 0;
        if (movedContraption == null)
            return lastGeneratedSpeed;
        int sails = ((BearingContraption) movedContraption.getContraption()).getSailBlocks() / AllConfigs.server().kinetics.windmillSailsPerRPM.get();
        return class_3532.method_15340(sails, 1, 16) * getAngleSpeedDirection();
    }

    @Override
    public boolean isWindmill() {
        return true;
    }

    protected float getAngleSpeedDirection() {
        RotationDirection rotationDirection = RotationDirection.values()[movementDirection.getValue()];
        return (rotationDirection == RotationDirection.CLOCKWISE ? 1 : -1);
    }

    @Override
    public void write(class_11372 view, boolean clientPacket) {
        view.method_71464("LastGenerated", lastGeneratedSpeed);
        view.method_71472("QueueAssembly", queuedReassembly);
        super.write(view, clientPacket);
    }

    @Override
    protected void read(class_11368 view, boolean clientPacket) {
        if (!wasMoved)
            lastGeneratedSpeed = view.method_71423("LastGenerated", 0);
        queuedReassembly = view.method_71433("QueueAssembly", false);
        super.read(view, clientPacket);
    }

    @Override
    public void addBehaviours(List<BlockEntityBehaviour<?>> behaviours) {
        movementDirection = new ServerScrollOptionBehaviour<>(RotationDirection.class, this);
        movementDirection.withCallback($ -> onDirectionChanged());
        behaviours.add(movementDirection);
    }

    @Override
    public List<CreateTrigger> getAwardables() {
        return List.of(AllAdvancements.WINDMILL, AllAdvancements.WINDMILL_MAXED);
    }

    private void onDirectionChanged() {
        if (!running)
            return;
        if (!field_11863.method_8608())
            updateGeneratedRotation();
    }

    @Override
    public boolean isWoodenTop() {
        return true;
    }

    public enum RotationDirection {
        CLOCKWISE,
        COUNTER_CLOCKWISE;
    }

}
